---
title: 네이버페이(주문형) 검수요청 항목
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제대행사 계약
seo:
  title: 네이버페이(주문형) 검수요청 항목
  description: >-
    네이버페이 주문형의 검수 절차를 진행하기 위해 필요한 정보를 안내해 드립니다. 아래 정보를 작성하시고 네이버페이 측으로 주문형 검수
    요청해 주시면 테스트연동을 위한 테스트 환경설정 요청을 드리겠습니다.
  keywords:
    - 네이버페이
    - 주문형
    - 검수
tags:
  - 네이버페이(주문형)
  - 결제대행사 계약
pgCompanies:
  - 네이버페이(주문형)
searchTags:
  - 주문형검수
  - 주문형 검수
  - 네이버페이 검수
  - 네이버페이검수
  - 네이버페이주문형검수
  - 네이버페이 주문형 검수
  - 검수 요청서
  - 검수요청서
  - 검수 절차
  - 검수절차
  - 검수 요청
  - 검수요청
datetime: 2024-03-03T11:24:33.405Z
---

### **자체개발 홈페이지로 네이버페이 연동하기**

<Callout content="1. 자체적으로 개발하시는 경우 네이버페이 검수팀으로 테스트 환경설정에 대한 요청이 필요합니다.
2. 아래의 사업자 정보를 기입하여 포트원 고객지원팀(cs@portone.io)으로 전달주시면 네이버페이측으로 테스트환경 설정요청 드리도록 하겠습니다.
3. 전달주시는 내용은&quot;포트원→네이버페이&quot;로 전달되며 네이버페이 담당자 확인 후 검수가 진행됩니다." icon="💡" title="참고사항" />

### **네이버페이 주문형 검수 요청 정보**

**사업자 정보**

- 로그인 ID : 페이센터 Shop ID (가입승인 후 발급. 예 : np\_\*\*\*\*\*\*\* )
- 상품정보XML :  URL 형태로만 가능\
  (포트원에서는 네이버페이 2.1 장바구니 버전으로 연동되어있으므로 첨부드린 매뉴얼 참조 바랍니다)
- 테스트용 상세페이지 URL : 테스트용 상세페이지는 네이버페이 연동하실 전체상품의 URL을 전달 주시기 바랍니다.(네이버페이 구매버튼이 활성화 되어야 함)
- 테스트용 장바구니 페이지 URL : 네이버페이 구매버튼이 활성화 되어야 함. 장바구니 미사용시 " 사용안함"으로 기재)
- 담당자명, 연락처, 이메일 :
- 사업자등록번호 :
- 상호 :
- 대표자명 :

### **요청정보 작성시 참고사항**

<Callout title="유의사항" content="1. 네이버페이(주문형) 사이트 검수 관련하여 요청드리는 상품정보 XML 및 테스트용 상세 페이지와 장바구니 페이지는 테스트환경 검수시  필수적으로 필요한 정보입니다.
2. 검수는  실제 판매되는 전체상품을 대상으로 이루어져야 하며, 특정 상품에만 적용되어 있는 구조로는 검수 진행이 어렵습니다.
3. 쇼핑몰에 등록된 모든 상품에 대한 정보를 기재하시어, URL주소의 형태로 전달주시기 바라며, 상품별 기입이 필요한 내용은 판매 상품 유형에 따라 달라지므로 관련 내용은 네이버페이에서 제공되는 개발가이드를 참고 해주시길 바랍니다." icon="❗" />

아래로, 상품XML관련하여 예시 전달 드리오니 참고하시어 실제 판매하실 상품 기준으로 작성 바랍니다

### **참고가이드**

- [네이버페이 주문형 연동매뉴얼 보러가기 ↗](https://github.com/iamport/iamport-manual/blob/master/NAVERPAY/sample/naverpay-order.md)
- 상품정보XML, 찜하기 구성 참고
  - [네이버페이 배송비 정책관련 매뉴얼 보러가기 ↗](https://github.com/iamport/iamport-manual/blob/master/NAVERPAY/sample/naverpay-shipping.md)
